@@ -14,7 +14,10 @@
 
 from datetime import datetime
 from StringIO import StringIO
-import simplejson
+try:
+    import json as simplejson
+except:
+    import simplejson
 import sys, traceback
 import logging
 import json_tools, test_jsonrpc
